<?php
global $opt_name;
$taxonomy_model = new \Lisfinity\Models\Taxonomies\TaxonomiesAdminModel();
Redux::set_section( $opt_name, [
		'title'      => __( 'Header Setup', 'lisfinity-core' ),
		'id'         => 'header-settings',
		'desc'       => __( 'Setting to adjust various header options', 'lisfinity-core' ),
		'icon'       => 'fa fa-list-alt',
		'customizer' => true,
		'subsection' => false,
		'fields'     => [
			[
				'id'         => '_header-type',
				'type'       => 'select',
				'title'      => __( 'Header Type', 'lisfinity-core' ),
				'desc'       => __( 'Choose the type of the header you wish to use.', 'lisfinity-core' ),
				'options'    => [
					'default' => __( 'Default', 'lisfinity-core' ),
					'custom'  => __( 'Custom (Elementor)', 'lisfinity-core' ),
				],
				'default'    => 'default',
				'select2'    => [
					'allowClear' => false,
				],
				'customizer' => true,
			],
			[
				'id'       => '_header-post',
				'type'     => 'select',
				'title'    => __( 'Header Post', 'lisfinity-core' ),
				'desc'     => __( 'Choose the header you wish to display from the list of created ones.', 'lisfinity-core' ),
				'options'  => lisfinity_get_post_type_select( 'lisfinity_header' ),
				'default'  => '',
				'required' => [ '_header-type', '=', 'custom' ],
			],
			[
				'id'       => '_header-sticky-post',
				'type'     => 'select',
				'title'    => __( 'Sticky Header Post', 'lisfinity-core' ),
				'desc'     => __( 'Choose the sticky header you wish to display from the list of created ones or leave empty to disable sticky header.', 'lisfinity-core' ),
				'options'  => lisfinity_get_post_type_select( 'lisfinity_header' ),
				'default'  => '',
				'required' => [ '_header-type', '=', 'custom' ],
			],
			[
				'id'         => '_header-sticky',
				'type'       => 'switch',
				'title'      => __( 'Sticky Header', 'lisfinity-core' ),
				'desc'       => __( 'Enable sticky header where possible', 'lisfinity-core' ),
				'default'    => false,
				'customizer' => true,
				'required'   => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_header-keyword',
				'type'     => 'switch',
				'title'    => __( 'Header Keyword Search', 'lisfinity-core' ),
				'desc'     => __( 'Enable keyword search field in the header', 'lisfinity-core' ),
				'default'  => true,
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_header-taxonomy',
				'type'     => 'select',
				'title'    => __( 'Header Taxonomies', 'lisfinity-core' ),
				'desc'     => __( 'Enable specific taxonomy field in the header', 'lisfinity-core' ),
				'options'  => $taxonomy_model->get_taxonomies( false ),
				'default'  => '',
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_header-cart',
				'type'     => 'switch',
				'title'    => __( 'Show Cart', 'lisfinity-core' ),
				'desc'     => __( 'Enable cart in the header', 'lisfinity-core' ),
				'default'  => false,
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_header-compare',
				'type'     => 'switch',
				'title'    => __( 'Show Listings Compare Button', 'lisfinity-core' ),
				'desc'     => __( 'Enable listings compare button in the header', 'lisfinity-core' ),
				'default'  => true,
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_header-avatar',
				'type'     => 'switch',
				'title'    => __( 'Show User Avatar', 'lisfinity-core' ),
				'desc'     => __( 'Enable user avatar in the header', 'lisfinity-core' ),
				'default'  => true,
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_button-submit-enable',
				'type'     => 'switch',
				'title'    => __( 'Show Submit Listing Button', 'lisfinity-core' ),
				'desc'     => __( 'Enable submit listing button in the header', 'lisfinity-core' ),
				'default'  => true,
				'required' => [ '_header-type', '=', 'default' ],
			],
			[
				'id'       => '_button-submit-text',
				'type'     => 'text',
				'title'    => __( 'Submit Listing Button Text', 'lisfinity-core' ),
				'desc'     => __( 'Displayed text on the listing submit button in the header', 'lisfinity-core' ),
				'default'  => __( 'Submit Listing', 'lisfinity-core' ),
				'required' => [ '_button-submit-enable', '=', '1' ],
			],
		],
	]
);

Redux::set_section( $opt_name, [
		'title'      => __( 'Mobile Menu Setup', 'lisfinity-core' ),
		'id'         => 'mobile-menu-settings',
		'desc'       => __( 'Setting to adjust various mobile menu options', 'lisfinity-core' ),
		'icon'       => 'fa fa-mobile',
		'subsection' => true,
		'fields'     => [
			[
				'id'       => '_mobile-menu-social-text',
				'type'     => 'text',
				'title'    => __( 'Mobile Menu Social Text', 'lisfinity-core' ),
				'desc'     => __( 'Type the text that you want to display above the social icons in the mobile menu', 'lisfinity-core' ),
				'default'  => __( 'Lisfinity on social networks', 'lisfinity-core' )
			],
			[
				'id'      => '_mobile-menu-social',
				'type'    => 'select',
				'title'   => __( 'Mobile Menu Social Icons', 'lisfinity-core' ),
				'desc'    => __( 'Set the social icons you wish to display in the mobile menu', 'lisfinity-core' ),
				'options' => lisfinity_get_available_social_networks(),
				'default' => '',
				'multi'   => true,
			],
			[
				'id'          => '_mobile-menu-facebook',
				'type'        => 'text',
				'title'       => __( 'Facebook URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your facebook account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://facebook.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'facebook' ],
			],
			[
				'id'          => '_mobile-menu-twitter',
				'type'        => 'text',
				'title'       => __( 'Twitter URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your twitter account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://twitter.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'twitter' ],
			],
			[
				'id'          => '_mobile-menu-instagram',
				'type'        => 'text',
				'title'       => __( 'Instagram URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your instagram account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://instagram.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'instagram' ],
			],
			[
				'id'          => '_mobile-menu-dribbble',
				'type'        => 'text',
				'title'       => __( 'Dribbble URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your dribbble account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://dribbble.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'dribbble' ],
			],
			[
				'id'          => '_mobile-menu-linkedin',
				'type'        => 'text',
				'title'       => __( 'Linkedin URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your linkedin account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://linkedin.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'linkedin' ],
			],
			[
				'id'          => '_mobile-menu-youtube',
				'type'        => 'text',
				'title'       => __( 'YouTube URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your youtube account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://youtube.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'youtube' ],
			],
			[
				'id'          => '_mobile-menu-reddit',
				'type'        => 'text',
				'title'       => __( 'Reddit URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your reddit account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://reddit.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'reddit' ],
			],
			[
				'id'          => '_mobile-menu-pinterest',
				'type'        => 'text',
				'title'       => __( 'Pinterest URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your pinterest account.', 'lisfinity-core' ),
				'placeholder' => esc_html( 'https://pinterest.com/lisfinity' ),
				'required'    => [ '_mobile-menu-social', 'contains', 'pinterest' ],
			],
			[
				'id'          => '_mobile-menu-medium',
				'type'        => 'text',
				'title'       => __( 'Medium URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your medium account.', 'lisfinity-core' ),
				'placeholder' => 'https://medium.com/lisfinity',
				'required'    => [ '_mobile-menu-social', 'contains', 'medium' ],
			],
			[
				'id'          => '_mobile-menu-vk',
				'type'        => 'text',
				'title'       => __( 'VKontakte URL', 'lisfinity-core' ),
				'desc'        => __( 'Enter the link to your vk account.', 'lisfinity-core' ),
				'placeholder' => 'https://vk.com/lisfinity',
				'required'    => [ '_mobile-menu-social', 'contains', 'vk' ],
			],
		],
	]
);
